@@ -1,6 +1,6 @@
 # stdlib
 import json
-from typing import List, Optional
+from typing import Optional
 
 # third party
 import typer
@@ -91,6 +91,7 @@ RUN_ID_OPTIONAL = typer.Option(
 SERVICE_TOKEN_ID = typer.Option(
     ..., '--service-token-id', '-t', help='Numeric ID of the service token.'
 )
+STATE = typer.Option(None, '--state', help='1 = active, 2 = deleted')
 TOKEN = typer.Option(
     None,
     '--token',
@@ -111,6 +112,12 @@ def _dbt_api_request(ctx: typer.Context, property: str, method: str, *args, **kw
 
 
 def _dbt_cloud_request(ctx: typer.Context, method: str, *args, **kwargs):
+    if kwargs.get('include_related', None) is not None:
+        try:
+            include_related = kwargs['include_related']
+            kwargs['include_related'] = json.loads(include_related)
+        except ValueError as e:
+            raise ValueError(f'"{include_related}" is not a valid JSON string') from e
     _dbt_api_request(ctx, 'cloud', method, *args, **kwargs)
 
 
@@ -525,6 +532,82 @@ def get_models(
     )
 
 
+@app.command()
+def get_most_recent_run(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    include_related: str = INCLUDE_RELATED,
+    job_id: int = typer.Option(
+        None, '--job-id', '-j', help='Numeric ID of job to retrieve'
+    ),
+    environment_id: int = typer.Option(
+        None, '--environment-id', '-e', help='Numeric ID of environment to retrieve'
+    ),
+    project_id: str = typer.Option(
+        None, '--project-id', '-p', help='The project ID or IDs'
+    ),
+    deferring_run_id: int = typer.Option(
+        None, '--deferring-run-id', help='The deferring run ID'
+    ),
+    status: str = typer.Option(
+        None, '--status', help='Status to apply when listing runs'
+    ),
+):
+    if status is not None:
+        try:
+            status = json.loads(status)
+        except ValueError:
+            pass
+
+    _dbt_cloud_request(
+        ctx,
+        'get_most_recent_run',
+        account_id,
+        include_related=include_related,
+        job_definition_id=job_id,
+        environment_id=environment_id,
+        project_id=json.loads(project_id) if project_id else project_id,
+        deferring_run_id=deferring_run_id,
+        status=status,
+    )
+
+
+@app.command()
+def get_most_recent_run_artifact(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    path: str = typer.Option(
+        ..., '--path', '-f', help='Name of artifact to retrieve (e.g. manifest.json)'
+    ),
+    job_id: int = typer.Option(
+        None, '--job-id', '-j', help='Numeric ID of job to retrieve'
+    ),
+    environment_id: int = typer.Option(
+        None, '--environment-id', '-e', help='Numeric ID of environment to retrieve'
+    ),
+    project_id: str = typer.Option(
+        None, '--project-id', '-p', help='The project ID or IDs'
+    ),
+    deferring_run_id: int = typer.Option(
+        None, '--deferring-run-id', help='The deferring run ID'
+    ),
+    step: int = typer.Option(
+        None, '--step', '-s', help='Index of the step in the run to retrieve'
+    ),
+):
+    _dbt_cloud_request(
+        ctx,
+        'get_most_recent_run_artifact',
+        account_id,
+        path,
+        job_definition_id=job_id,
+        environment_id=environment_id,
+        project_id=json.loads(project_id) if project_id else project_id,
+        deferring_run_id=deferring_run_id,
+        step=step,
+    )
+
+
 @app.command()
 def get_seed(
     ctx: typer.Context,
@@ -667,7 +750,7 @@ def get_run(
     ctx: typer.Context,
     account_id: int = ACCOUNT_ID,
     run_id: int = RUN_ID,
-    include_related: List[str] = INCLUDE_RELATED,
+    include_related: str = INCLUDE_RELATED,
 ):
     """Get run by ID for a specific account."""
     _dbt_cloud_request(
@@ -815,10 +898,48 @@ def list_credentials(
 def list_environments(
     ctx: typer.Context,
     account_id: int = ACCOUNT_ID,
-    project_id: int = PROJECT_ID,
+    project_id: str = typer.Option(
+        None, '--project-id', '-p', help='The project ID or IDs'
+    ),
+    dbt_version: str = typer.Option(
+        None,
+        '--dbt-version',
+        help='The dbt version(s) used in the environment',
+    ),
+    name: str = typer.Option(
+        None,
+        '--name',
+        help='The name of the environment',
+    ),
+    type: str = typer.Option(
+        None,
+        '--type',
+        help='The type of environment (deployment or development)',
+    ),
+    state: str = STATE,
+    offset: int = OFFSET,
+    limit: int = LIMIT,
+    order_by: str = ORDER_BY,
 ):
-    """List environments for a specific account and project."""
-    _dbt_cloud_request(ctx, 'list_environments', account_id, project_id)
+    """List environments in an account"""
+    try:
+        dbt_version = json.loads(dbt_version)
+    except (ValueError, TypeError):
+        pass
+
+    _dbt_cloud_request(
+        ctx,
+        'list_environments',
+        account_id,
+        project_id=json.loads(project_id) if project_id else project_id,
+        dbt_version=dbt_version,
+        name=name,
+        type=type,
+        state=state,
+        offset=offset,
+        limit=limit,
+        order_by=order_by,
+    )
 
 
 @app.command()
@@ -843,9 +964,18 @@ def list_invited_users(ctx: typer.Context, account_id: int = ACCOUNT_ID):
 def list_jobs(
     ctx: typer.Context,
     account_id: int = ACCOUNT_ID,
-    project_id: int = typer.Option(
-        None, '--project-id', '-p', help='Numeric ID of the project to retrieve.'
+    environment_id: int = typer.Option(
+        None,
+        '--environment-id',
+        '-e',
+        help='Numeric ID of the environment to retrieve',
     ),
+    project_id: str = typer.Option(
+        None, '--project-id', '-p', help='The project ID or IDs'
+    ),
+    state: str = STATE,
+    offset: int = OFFSET,
+    limit: int = LIMIT,
     order_by: str = ORDER_BY,
 ):
     """List jobs in an account or specific project"""
@@ -853,15 +983,36 @@ def list_jobs(
         ctx,
         'list_jobs',
         account_id,
+        environment_id=environment_id,
+        project_id=json.loads(project_id) if project_id else project_id,
+        state=state,
+        offset=offset,
+        limit=limit,
         order_by=order_by,
-        project_id=project_id,
     )
 
 
 @app.command()
-def list_projects(ctx: typer.Context, account_id: int = ACCOUNT_ID):
+def list_projects(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    project_id: str = typer.Option(
+        None, '--project-id', '-p', help='The project ID or IDs'
+    ),
+    state: str = STATE,
+    offset: int = OFFSET,
+    limit: int = LIMIT,
+):
     """List projects for a specified account"""
-    _dbt_cloud_request(ctx, 'list_projects', account_id)
+    _dbt_cloud_request(
+        ctx,
+        'list_projects',
+        account_id,
+        project_id=json.loads(project_id) if project_id else project_id,
+        state=state,
+        offset=offset,
+        limit=limit,
+    )
 
 
 @app.command()
@@ -896,16 +1047,25 @@ def list_run_artifacts(
 def list_runs(
     ctx: typer.Context,
     account_id: int = ACCOUNT_ID,
-    include_related: List[str] = INCLUDE_RELATED,
+    include_related: str = INCLUDE_RELATED,
     job_id: int = typer.Option(
         None, '--job-id', '-j', help='Numeric ID of job to retrieve'
     ),
+    environment_id: int = typer.Option(
+        None, '--environment-id', '-e', help='Numeric ID of environment to retrieve'
+    ),
+    project_id: str = typer.Option(
+        None, '--project-id', '-p', help='The project ID or IDs'
+    ),
+    deferring_run_id: int = typer.Option(
+        None, '--deferring-run-id', help='The deferring run ID'
+    ),
+    status: str = typer.Option(
+        None, '--status', help='Status to apply when listing runs'
+    ),
     order_by: str = ORDER_BY,
     offset: int = OFFSET,
     limit: int = LIMIT,
-    status: str = typer.Option(
-        None, '--status', help='Status to apply when listing runs'
-    ),
 ):
     if status is not None:
         try:
@@ -919,6 +1079,9 @@ def list_runs(
         account_id,
         include_related=include_related,
         job_definition_id=job_id,
+        environment_id=environment_id,
+        project_id=json.loads(project_id) if project_id else project_id,
+        deferring_run_id=deferring_run_id,
         order_by=order_by,
         offset=offset,
         limit=limit,
@@ -1008,7 +1171,7 @@ def trigger_autoscaling_ci_job(
     job_id: int = JOB_ID,
     payload: str = PAYLOAD,
     should_poll: bool = typer.Option(
-        True,
+        False,
         help='Poll until job completion (status is one of success, failure, or '
         'cancelled)',
     ),
